@@ -10,7 +10,7 @@ use Carp 'confess';
 use Pod::Usage 'pod2usage';
 use List::Util 'min';
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 
 sub new {
   my $class = shift;
@@ -268,6 +268,9 @@ Main part of build process is combination of L<Giblog::API>.
     # Read config
     my $config = $api->read_config;
     
+    # Copy static files to public
+    $api->copy_static_files_to_public;
+
     # Get files in templates directory
     my $files = $api->get_templates_files;
     
